@@ -41,7 +41,8 @@ from .exec import (
     insert_from_df,
     insert_from_json,
     truncate_table,
-    drop_table
+    drop_table,
+    show_tables
 )
 
 from .sql_exec import sql
