@@ -1,8 +1,8 @@
-from .dialect import Dialect
-from .loader import Loader
-from . import sql_support
 from executor import DBError
 from typing import Collection, Iterable
+from .loader import Loader
+from .dialect import Dialect, Engine
+from . import sql_support
 from .log_support import logger, insert_log, save_log
 from executor import execute as _execute, select as _select, select_one as _select_one, do_select as _do_select,\
     save as _save, batch_execute as _batch_execute, get as _get, query as _query, query_one as _query_one
@@ -383,10 +383,16 @@ def insert_from_json(file_name: str, table_name: str, encoding='utf-8') -> int:
 
 
 def truncate_table(table_name: str) -> int:
-    """ sqlexec.truncate('person') """
+    """ sqlexec.truncate_table('person') """
     return _execute(Dialect.get_truncate_sql(table_name))
 
 
 def drop_table(table_name: str) -> int:
-    """ sqlexec.drop('person') """
+    """ sqlexec.drop_table('person') """
     return _execute('DROP TABLE %s' % Dialect.get_dialect_str(table_name))
+
+
+def show_tables(schema: str = None):
+    if schema and Dialect.curr_engine() != Engine.SQLITE:
+        _execute('use %s' % schema)
+    return [table[0] for table in _select(Dialect.show_tables_sql())]
