@@ -1,10 +1,11 @@
-#！/usr/bin/env python3
+# !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
+from typing import Sequence, Tuple
 from .loader import Loader
 from . import exec, sql_support
+from .dialect import Dialect, Engine
 from .constant import LIMIT_1, SELECT_COUNT
-from typing import Sequence, Tuple
 from .sql_support import get_table_select_sql
 
 
@@ -154,7 +155,7 @@ class WhereExec:
         """
          sqlexec.table('person').where(name='李四').exists()
         """
-        return self.get('1') == 1
+        return self.get(1) == 1
 
     def select(self, *columns):
         """
@@ -189,7 +190,10 @@ class WhereExec:
         sqlexec.table('person').where(name='李四').delete()
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
-        sql = 'DELETE FROM %s %s' % (self.table, where)
+        sql = 'DELETE FROM %s %s' % (Dialect.get_dialect_str(self.table), where)
+        if Dialect.curr_engine() in (Engine.MYSQL, Engine.SQLITE):
+            sql = '{} LIMIT ?'.format(sql)
+            args = [*args, LIMIT_1]
         return self.exec.do_execute(sql, *args)
 
     def update(self, **kwargs):
@@ -199,8 +203,11 @@ class WhereExec:
         where, args, _ = get_where_arg_limit(**self.where_condition)
         update_cols, update_args = zip(*kwargs.items())
         args = [*update_args, *args]
-        update_cols = ', '.join(['{} = ?'.format(col) for col in update_cols])
-        sql = 'UPDATE {} SET {} {}'.format(self.table, update_cols, where)
+        update_cols = ', '.join(['{} = ?'.format(Dialect.get_dialect_str(col)) for col in update_cols])
+        sql = 'UPDATE {} SET {} {}'.format(Dialect.get_dialect_str(self.table), update_cols, where)
+        if Dialect.curr_engine() in (Engine.MYSQL, Engine.SQLITE):
+            sql = '{} LIMIT ?'.format(sql)
+            args = [*args, LIMIT_1]
         return self.exec.do_execute(sql, *args)
 
     def load(self, *columns) -> Loader:
@@ -231,6 +238,7 @@ class WhereExec:
         sql = get_table_select_sql(self.table, where, LIMIT_1, *columns)
         return sql, args
 
+
 class ColumnExec:
 
     def __init__(self, table_exec, *columns):
@@ -452,48 +460,48 @@ def table(table_name: str) -> TableExec:
 
 def get_condition_arg(k: str, v: object):
     if k.endswith("__eq"):
-        return "{} = ?".format(k[:-4]), v
+        return "{} = ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__ne"):
-        return "{} != ?".format(k[:-4]), v
+        return "{} != ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__gt"):
-        return "{} > ?".format(k[:-4]), v
+        return "{} > ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__lt"):
-        return "{} < ?".format(k[:-4]), v
+        return "{} < ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__ge"):
-        return "{} >= ?".format(k[:-4]), v
+        return "{} >= ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__gte"):
-        return "{} >= ?".format(k[:-5]), v
+        return "{} >= ?".format(Dialect.get_dialect_str(k[:-5])), v
     if k.endswith("__le"):
-        return "{} <= ?".format(k[:-4]), v
+        return "{} <= ?".format(Dialect.get_dialect_str(k[:-4])), v
     if k.endswith("__lte"):
-        return "{} <= ?".format(k[:-5]), v
+        return "{} <= ?".format(Dialect.get_dialect_str(k[:-5])), v
     if k.endswith("__isnull"):
-        return "{} is {}".format(k[:-8], 'null' if v else 'not null'), None
+        return "{} is {}".format(Dialect.get_dialect_str(k[:-8]), 'null' if v else 'not null'), None
     if k.endswith("__in") and isinstance(v, Sequence) and not isinstance(v, str):
-        return "{} in({})".format(k[:-4], ','.join(['?' for _ in v])), v
+        return "{} in({})".format(Dialect.get_dialect_str(k[:-4]), ','.join(['?' for _ in v])), v
     if k.endswith("__in"):
-        return "{} in({})".format(k[:-4], '?'), v
+        return "{} in({})".format(Dialect.get_dialect_str(k[:-4]), '?'), v
     if k.endswith("__not_in") and isinstance(v, Sequence) and not isinstance(v, str):
-        return "{} not in({})".format(k[:-8], ','.join(['?' for _ in v])), v
+        return "{} not in({})".format(Dialect.get_dialect_str(k[:-8]), ','.join(['?' for _ in v])), v
     if k.endswith("__not_in"):
-        return "{} not in({})".format(k[:-8], '?'), v
+        return "{} not in({})".format(Dialect.get_dialect_str(k[:-8]), '?'), v
     if k.endswith("__like"):
-        return "{} like ?".format(k[:-6], '?'), v
+        return "{} like ?".format(Dialect.get_dialect_str(k[:-6])), '%{}%'.format(v)
     if k.endswith("__startswith"):
-        return "{} like ?".format(k[:-12]), '{}%'.format(v)
+        return "{} like ?".format(Dialect.get_dialect_str(k[:-12])), '{}%'.format(v)
     if k.endswith("__endswith"):
-        return "{} like ?".format(k[:-10]), '%{}'.format(v)
+        return "{} like ?".format(Dialect.get_dialect_str(k[:-10])), '%{}'.format(v)
     if k.endswith("__contains"):
-        return "{} like ?".format(k[:-10]), '%{}%'.format(v)
+        return "{} like ?".format(Dialect.get_dialect_str(k[:-10])), '%{}%'.format(v)
     if k.endswith("__range") and isinstance(v, Sequence) and 2 == len(v) and not isinstance(v, str):
         col = k[:-7]
-        return "{} >= ? and {} <= ?".format(col, col), v
+        return "{} >= ? and {} <= ?".format(Dialect.get_dialect_str(col), Dialect.get_dialect_str(col)), v
     if k.endswith("__between") and isinstance(v, Sequence) and 2 == len(v) and not isinstance(v, str):
-        return "{} between ? and ?".format(k[:-9]), v
+        return "{} between ? and ?".format(Dialect.get_dialect_str(k[:-9])), v
     if k.endswith("__range") or k.endswith("__between"):
         return ValueError("Must is instance of Sequence with length 2 when use range or between statement")
 
-    return "{} = ?".format(k), v
+    return "{} = ?".format(Dialect.get_dialect_str(k)), v
 
 
 def get_where_arg_limit(**kwargs):
